@@ -1,58 +1,54 @@
 import gc
+import sys
+
+import pytest
 
 from multidict._compat import USE_CYTHON
+from multidict._multidict_py import istr as _istr  # noqa: E402
 
 if USE_CYTHON:
     from multidict._multidict import istr
 
-from multidict._multidict_py import istr as _istr  # noqa: E402
+
+IMPLEMENTATION = getattr(sys, "implementation")  # to suppress mypy error
 
 
 class IStrMixin:
 
-    cls = None
+    cls = NotImplemented
 
     def test_ctor(self):
         s = self.cls()
-        assert '' == s
+        assert "" == s
 
     def test_ctor_str(self):
-        s = self.cls('a')
-        assert 'A' == s
-
-    def test_ctor_str_uppercase(self):
-        s = self.cls('A')
-        assert 'A' == s
+        s = self.cls("aBcD")
+        assert "aBcD" == s
 
     def test_ctor_istr(self):
-        s = self.cls('A')
+        s = self.cls("A")
         s2 = self.cls(s)
-        assert 'A' == s
-        assert s is s2
+        assert "A" == s
+        assert s == s2
 
     def test_ctor_buffer(self):
-        s = self.cls(b'a')
-        assert "B'A'" == s
+        s = self.cls(b"aBc")
+        assert "b'aBc'" == s
 
     def test_ctor_repr(self):
         s = self.cls(None)
-        assert 'None' == s
-
-    def test_title(self):
-        s = self.cls('a')
-        assert s is s.title()
+        assert "None" == s
 
     def test_str(self):
-        s = self.cls('a')
+        s = self.cls("aBcD")
         s1 = str(s)
-        assert s1 == 'A'
+        assert s1 == "aBcD"
         assert type(s1) is str
 
-    def xtest_eq(self):
-        s1 = 'Abc'
+    def test_eq(self):
+        s1 = "Abc"
         s2 = self.cls(s1)
         assert s1 == s2
-        assert s1.lower() == s2
 
 
 class TestPyIStr(IStrMixin):
@@ -60,10 +56,13 @@ class TestPyIStr(IStrMixin):
 
     @staticmethod
     def _create_strs():
-        _istr('foobarbaz')
+        _istr("foobarbaz")
         istr2 = _istr()
         _istr(istr2)
 
+    @pytest.mark.skipif(
+        IMPLEMENTATION.name != "cpython", reason="PyPy has different GC implementation"
+    )
     def test_leak(self):
         gc.collect()
         cnt = len(gc.get_objects())
@@ -76,5 +75,6 @@ class TestPyIStr(IStrMixin):
 
 
 if USE_CYTHON:
+
     class TestIStr(IStrMixin):
         cls = istr
